/*
 * dns.c
 */

#define LIBNFSNAPI_BUILDING_LIB

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "dns.h"
#include "error.h"
#include "mgr.h"


libnfsnapi_dns_t *libnfsnapi_dns_create(libnfsnapi_mgr_t *mgr,
						const char *domain)
{
	libnfsnapi_dns_t *dns;

	dns = (libnfsnapi_dns_t *) malloc(sizeof(libnfsnapi_dns_t));
	if (!dns) {
		mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return NULL;
	}

	dns->mgr = mgr;

	dns->domain = strdup(domain);
	if (!dns->domain) {
		mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		free(dns);
		return NULL;
	}

	return dns;
}

void libnfsnapi_dns_destroy(libnfsnapi_dns_t *dns)
{
	free(dns->domain);
	free(dns);
}

/* Returns minTTL in seconds, or a negative number on error. */
int libnfsnapi_dns_minTTL(libnfsnapi_dns_t *dns)
{
	char *request_uri;
	int err;

	asprintf(&request_uri, "/dns/%s/minTTL", dns->domain);
	if (!request_uri) {
		dns->mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return -1;
	}
	err = libnfsnapi_mgr_do(dns->mgr, LIBNFSNAPI_MGR_HTTP_GET,
				request_uri, NULL);
	free(request_uri);

	if (err)
		return -1;

	return libnfsnapi_mgr_result_int(dns->mgr);
}

int libnfsnapi_dns_minTTL_set(libnfsnapi_dns_t *dns, int minTTL)
{
	char *request_uri, *put_data;
	int err;

	asprintf(&put_data, "%d", minTTL);
	if (!put_data) {
		dns->mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return -1;
	}

	asprintf(&request_uri, "/dns/%s/minTTL", dns->domain);
	if (!request_uri) {
		free(put_data);
		dns->mgr->error = LIBNFSNAPI_ERROR_MEMORY;
		return -1;
	}
	err = libnfsnapi_mgr_do(dns->mgr, LIBNFSNAPI_MGR_HTTP_PUT,
				request_uri, put_data);
	free(put_data);
	free(request_uri);

	if (err)
		return -1;

	return 0;
}
