/*
 * dns.h
 */

#ifndef __LIBNFSNAPI_DNS_H__
#define __LIBNFSNAPI_DNS_H__

/**
 * @defgroup DNS
 *
 * @{
 */

#include "mgr.h"

/** DNS handle. Users should treat this structure as opaque. */
typedef struct {
#ifdef LIBNFSNAPI_BUILDING_LIB
	/* Opaque! Don't touch anything here! */
	libnfsnapi_mgr_t *mgr;

	char *domain;
#endif
} libnfsnapi_dns_t;

/**
 * Create a DNS object.
 *
 * @param mgr A Manager object, created with \ref libnfsnapi_mgr_create.
 * @param domain The domain name. It will be copied internally.
 * \return A DNS object, or NULL on failure.
 */
libnfsnapi_dns_t *libnfsnapi_dns_create(libnfsnapi_mgr_t *mgr,
						const char *domain);
/**
 * Destroy a DNS object, and free all memory associated with it.
 * Do not use this pointer after calling this function.
 */
void libnfsnapi_dns_destroy(libnfsnapi_dns_t *dns);
/**
 * Retrieve the domain's minimum <em>Time-To-Live</em> (TTL).
 *
 * @param dns A DNS object.
 * \return Domain's minTTL, or a negative number on error.
 *		Use \ref libnfsnapi_mgr_error to find out the error code.
 * \see libnfsnapi_dns_minTTL_set
 */
int libnfsnapi_dns_minTTL(libnfsnapi_dns_t *dns);
/**
 * Set the domain's minimum <em>Time-To-Live</em> (TTL).
 *
 * @param dns A DNS object.
 * \return Zero on success, or a negative number on error.
 *		Use \ref libnfsnapi_mgr_error to find out the error code.
 * \see libnfsnapi_dns_minTTL
 */
int libnfsnapi_dns_minTTL_set(libnfsnapi_dns_t *dns, int minTTL);

/** @} */

#endif /* __LIBNFSNAPI_DNS_H__ */
