/*
 * demo.c -- A demonstration of using libNFSNapi for embedding in webpage
 */

#define LOGIN_NAME	"dsymonds"
#define SITE_NAME	"symonds"

/* Enable this for running on NFSNs servers. Some paths need to be
 * tweaked, but this will do it all for you. */
/* #define ON_NFSN */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include <libnfsnapi.h>



static char api_key[17];
static char acct_num[14];

/* Load the first 16 bytes from the file; return zero on success. */
/* Also, try to load an account number from the next line of it */
int load_api_key()
{
	char path[300], buf[50];
	FILE *f;

#ifndef ON_NFSN
	sprintf(path, "%s/.nfsn-apikey", getenv("HOME"));
#else
	sprintf(path, "/nfsn/content/%s/private/.nfsn-apikey", SITE_NAME);
#endif

	f = fopen(path, "r");
	if (!f) {
		perror("fopen");
		return 1;
	}

	/* printf("Loading API key from %s... ", path); */
	if (!fgets(buf, sizeof(buf), f)) {
		printf("d'oh!\n");
		perror("fgets");
		fclose(f);
		return 1;
	}
	while (strchr("\r\n", buf[strlen(buf) - 1]))
		buf[strlen(buf) - 1] = '\0';
	if (strlen(buf) != 16) {
		printf("hey!\nAPI keys are 16 characters!\n");
		fclose(f);
		return 1;
	}
	strcpy(api_key, buf);

	acct_num[0] = '\0';
	/* printf("Looking for account number on next line... "); */
	if (feof(f) || !fgets(buf, sizeof(buf), f)) {
		printf("nope!\n");
		fclose(f);
		return 0;
	}
	while (strchr("\r\n", buf[strlen(buf) - 1]))
		buf[strlen(buf) - 1] = '\0';
	if (strlen(buf) != 13) {
		printf("hey!\nAccount numbers are 13 characters!\n");
		fclose(f);
		return 1;
	}
	strcpy(acct_num, buf);

	fclose(f);
	return 0;
}

int main(void)
{
	libnfsnapi_mgr_t *mgr;
	libnfsnapi_account_t *account;
	int err;

	if (load_api_key() != 0) {
		printf("There's something wrong with ~/.nfsn-apikey!\n");
		printf("It should look something like this:\n");
		printf("\tp3kxmRKf9dk3l6ls\n");
		printf("\t1234-56789012\n");
		printf("The first line is your API key (required!)\n");
		printf("The second line is an account number (optional)\n");
		exit(1);
	}

	mgr = libnfsnapi_mgr_create(LOGIN_NAME, api_key, &err);
	if (!mgr) {
		printf("Damn! libnfsnapi_mgr_create failed!\n");
		printf("Error: %s\n", libnfsnapi_strerror(err));
		exit(1);
	}

	if (strlen(acct_num) > 0) {
		int tot;
		/* char *name; */

		account = libnfsnapi_account_create(mgr, acct_num);
		if (!account) {
			printf("Couldn't create an account!\n");
			printf("Error: %s\n", libnfsnapi_strerror(err));
			goto after_account_test;
		}
		/* name = libnfsnapi_account_friendlyName(account); */
		tot = libnfsnapi_account_balance(account,
						LIBNFSNAPI_BALANCE_ALL);
		libnfsnapi_account_destroy(account);

		if (tot >= 0) {
			printf("$%d.%02d", tot / 100, tot % 100);
		} else
			printf("Something failed: %s\n",
				libnfsnapi_mgr_strerror(mgr));
		/* if (name)
			free(name); */
	} else {
		printf("Don't have acc. number...\n");
	}
after_account_test:

	/* final cleanup */
	libnfsnapi_mgr_destroy(mgr);

	return 0;
}
